'use strict';

//TODO: es6 class?
var fs = require('fs');

/**
 * @param {Object} LoggerConfig
 * @constructor
 */
function LoggerConfig(path, options) {

    var transports_ = [];

    function generateTransports() {
        if (options['logzio']) {
            transports_.push(new (require('winston-logzio'))(options['logzio']));
        }
    }

    function getTransports() {

        // OLD: only DEV logging?
        // return process.env.NODE_ENV !== 'development' ?
        //     [new (require('winston-logzio'))(config.logzioOptions)]
        //     :
        //     [];
        return transports_;
    }

    /**
     * @param {String} filename
     * @returns {String}
     */
    function _buildFilePath(filename) {
        return path + '/' + filename + '.log';
    }

    /**
     * @desc try creating a log folder, should no overwrite existing files.
     * @param {String} path
     */
    function mkDirSync(path) {
        try {
            fs.mkdirSync(path);
        } catch (e) {
            if (e.code != 'EEXIST') throw e;
        }
    }

    //TODO: IIFE ?
    mkDirSync(path);
    generateTransports();

    /**
     * @desc
     * enhance this object with your own logger configuration for example
     */
    return {
        'error': {
            console: {
                level: 'error',
                colorize: true,
                label: ' error '
            },
            file: {
                filename: _buildFilePath('errors')
            },
            transports: getTransports()
        },
        'bootstrap': {
            console: {
                level: 'info',
                colorize: true,
                label: ' bootstrap '
            },
            file: {
                filename: _buildFilePath('boots')
            },
            transports: getTransports()
        },
        'private_api': {
            console: {
                level: 'info',
                colorize: true,
                label: ' api '
            },
            file: {
                filename: _buildFilePath('private_api')
            },
            transports: getTransports()
        }
    };
}

module.exports = LoggerConfig;