"use strict";

var winston = require('winston');
var _ = require('lodash');

/**
 * @param {Object} config
 * @constructor
 */
function Logger(config) {
    this.defaultLevel = 'info';

    _registerLoggers(config);
    /**
     * @desc
     * register loggers to winston
     * @param {Object} config - loggers config object
     * @private
     */
    function _registerLoggers(config) {
        _.mapKeys(config, function (val, key) {
            return winston.loggers.add(key, val);
        });
    }
}

/**
 * @desc
 * use this method when you want a general log or pass in type to use one of already registered loggers
 * @param {String} msg = message to log
 * @param {String} type - one of the prototype method error|private|bootstrap etc..
 * @param {String} level - (info|debug|error|...) log level
 */
Logger.prototype.log = function (msg, params, type, level) {
    var logger = winston.loggers.get(type);
    if (logger) {
        logger[level || this.defaultLevel](msg, params);
    } else {
        winston.log(msg);
    }
};

/**
 * @param {String} msg
 * @param {Object} params
 * @param {String} level
 */
Logger.prototype.error = function (msg, params, level) {
    winston.loggers.get('error')[level || 'error'](msg, params);
};

/**
 * @param {String} msg
 * @param {Object} params
 * @param {String} level
 */
Logger.prototype.private_api = function (msg, params, level) {
    winston.loggers.get('private_api')[level || 'info'](msg, params);
};

/**
 * @param {String} msg
 * @param {Object} params
 * @param {String} level
 */
Logger.prototype.bootstrap = function (msg, params, level) {
    winston.loggers.get('bootstrap')[level || 'info'](msg, params);
};

// @TODO require from config file
module.exports = function (params) {
    if (!params || !params.path || !params.options) {
        throw new Error('Please provide a valid parameters object: { path: (@String), options: {@Object) }');
    }
    var config = require('./logger-config')(params.path, params.options);
    return new Logger(config);
};